@@ -50,25 +50,25 @@ class ControllerCommand(Command):
     def command(self):
         try:
             self.verbose = 3
-            fo = FileOp(source_dir=os.path.dirname(__file__) + '/templates')
+            fo = FileOp(source_dir=os.path.join(os.path.dirname(__file__), 'templates'))
             try:
                 name, dir = fo.parse_path_name_args(self.args[0])
             except:
                 raise BadCommand('No egg_info directory was found')
-            fullname = '/'.join([dir, name])
-            if not fullname.startswith('/'): fullname = '/' + fullname
-            testname = fullname.replace('/', '_')[1:]
+            fullname = os.path.join(dir, name)
+            if not fullname.startswith(os.sep): fullname = os.sep + fullname
+            testname = fullname.replace(os.sep, '_')[1:]
             fo.template_vars.update({'name': name.title().replace('-', '_'),
-                                  'fullname':fullname,
-                                  'fname':'/'.join([dir, name]),
+                                  'fullname': fullname,
+                                  'fname': os.path.join(dir, name),
                                   'lname': name})
             fo.copy_file(template='controller.py_tmpl',
-                         dest='controllers' + '/' + dir, filename=name)
+                         dest=os.path.join('controllers', dir), filename=name)
             if not self.options.no_test:
                 fo.copy_file(template='test_controller.py_tmpl',
-                             dest='tests/functional', 
+                             dest=os.path.join('tests', 'functional'),
                              filename='test_'+testname)
         except:
             import sys
             msg = str(sys.exc_info()[1])
-            raise BadCommand('An unknown error ocurred, %s'%msg)
+            raise BadCommand('An unknown error ocurred, %s' % msg)
