@@ -3,7 +3,7 @@
 This module supplies pylons_config which handles setting up defaults
 for Myghty, Paste errorware, and prefixing Routes if necessary.
 """
-
+import os
 from myghty.resolver import *
 from paste.deploy.converters import asbool
 import pylons.myghtyroutes
@@ -91,7 +91,7 @@ class Config(object):
             app_uuid = app_conf.get('app_instance_uuid') or global_conf.get('app_instance_uuid')
             if not app_uuid:
                 raise Exception("No 'app__uuid' key specified in the config file.")
-            cache_dir = cache_dir + '/' + app_uuid
+            cache_dir = os.path.join(cache_dir, app_uuid)
         
         myghty_defaults = {}
         
@@ -110,8 +110,9 @@ class Config(object):
         # Standard Pylons configuration directives for Myghty
         myghty_defaults.setdefault('allow_globals', [])
                 
-        myghty_defaults['allow_globals'].extend(['c', 'h', 's', 'session', 'request', 'g', 'params'])
-        myghty_defaults['component_root'] = [{x.split('/')[-1] : x} for x in self.paths['templates']]
+        myghty_defaults['allow_globals'].extend(['c', 'h', 's', 'session', 'request', 'g'])
+        myghty_defaults['component_root'] = [{os.path.basename(path): path} for \
+                                             path in self.paths['templates']]
         
         # Pylons resolver strategy
         myghty_defaults['resolver_strategy'] = [
