@@ -61,10 +61,8 @@ class Controller(object):
             func(**kargs)
         else:
             argnames = argspec[0][1:]
-            kw = {}
-            for name in argnames:
-                if kargs.has_key(name): kw[name] = kargs[name]
-            func(**kw)
+            args = [kargs[name] for name in argnames if kargs.has_key(name)]
+            func(*args)
     
     def __call__(self, action, **kargs):
         """Makes our controller a callable to handle requests
@@ -73,10 +71,11 @@ class Controller(object):
         more fully.
         """
         kargs['action'] = action
+        action_method = action.replace('-', '_')
         if hasattr(self, '__before__'):
             self._inspect_call(self.__before__, **kargs)
-        if isinstance(getattr(self, kargs['action'], None), types.MethodType):
-            func = getattr(self, kargs['action'])
+        if isinstance(getattr(self, action_method, None), types.MethodType):
+            func = getattr(self, action_method)
             self._inspect_call(func, **kargs)
         else:
             if CONFIG['default']['debug'] == 'false':
@@ -97,17 +96,16 @@ class RPCController(Controller):
                 raise NotImplementedError('RPCController only supports %s action', RPCController.resource)
         d = pylons.m.request_args['_file'].read()
         params, method = xmlrpclib.loads(d)
-        
+
         if hasattr(self, '__before__'):
-            self.__before__(method, **params)
+            self.__before__(method, *params)
         if isinstance(getattr(self, method, None), types.MethodType):
-            self.__getattribute__(method)(**params)
+            res = self.__getattribute__(method)(*params)
         else:
-            res = 3#supposed to return xmlrpc fault thing
+            res = 3 #supposed to return xmlrpc fault thing
         pylons.m.write(xmlrpclib.dumps((res,)))
         if hasattr(self, '__after__'):
-            self.__after__(pylons, method, **params)
-
+            self.__after__(pylons, method, *params)
 
 class BricksController(Controller):
     """Allows Pylons applications to use Controllers from the Bricks framework
@@ -126,8 +124,7 @@ class BricksController(Controller):
 
     def view(self, template, namespace={}, format='cheetah'):
         if format == 'raw':
-            path = '/'.join(__file__.replace('\\','/').split('/')[:-2])+'/templates/cheetah_root/%s.tmpl'%template
-            fp = open(path,'r')
+            fp = open(self.template_path(template),'r')
             data = fp.read()
             fp.close()
             return data
@@ -141,10 +138,14 @@ class BricksController(Controller):
             return pylons.buffet.render('cheetah', template, namespace=namespace, as_string=True)
         
     def _write(self, template, data):
-        path = '/'.join(__file__.replace('\\','/').split('/')[:-2])+'/templates/cheetah_root/%s.tmpl'%template
-        fp = open(path,'w')
+        fp = open(self.template_path(template),'w')
         fp.write(data)
         fp.close()
+
+    def _template_path(self, template):
+        """Return the full path name to the specified template"""
+        root_path = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+        return os.path.join(root_path, 'templates', 'cheetah_root', '%s.tmpl' % template)
         
     def __call__(self, action, ARGS, **params):
         from pylons import m, request, buffet
