@@ -44,6 +44,9 @@ class ObjectProxy(object):
     def __iter__(self):
         return iter(self._get_object().keys())
     
+    def __len__(self):
+        return len(self._get_object())
+    
 
 class SessionProxy(ObjectProxy):
     """Retrieves the session thread-local from the Myghty request"""
