@@ -195,21 +195,12 @@ class Helpers(object):
         else:
             from pkg_resources import resource_string, resource_stream, resource_exists, resource_filename
             from pylons.i18n.translation import egg_translation
-            if not resource_exists(project_name, 'i18n/%s/LC_MESSAGES'%(lang)):
-                raise LanguageError(
-                    'Langauge catalog %s not found'%repr(
-                        '%s/i18n/%s/LC_MESSAGES'%(
-                            project_name,
-                            lang
-                        )
-                    )
-                )
-            self.__dict__['_local'].translator = egg_translation(
-                project_name, 
-                lang = 'i18n/%s/LC_MESSAGES'%(
-                    lang
-                )
-            )
+            catalog_path = os.path.join('i18n', lang, 'LC_MESSAGES')
+            if not resource_exists(project_name, catalog_path):
+                raise LanguageError('Langauge catalog %s not found' % \
+                                    os.path.join(project_name, catalog_path))
+            self.__dict__['_local'].translator = \
+                egg_translation(project_name, lang=catalog_path)
 
     def get_lang(self):
         return self.__dict__['_local'].lang
@@ -272,9 +263,10 @@ class Buffet(object):
         """
         for char in ['/','\\']:
             if char in template_name:
-                raise BuffetError('Templates should be specified as module paths relative to the '
-                'template root and therefore cannot contain %s characters'%repr(char))
-
+                raise BuffetError('Templates should be specified as module '
+                    'paths relative to the template root and therefore cannot '
+                    'contain %s characters' % repr(char))
+        
         def update_namespace(namespace):
             d = {}
             for k,v in namespace.items():
@@ -292,12 +284,13 @@ class Buffet(object):
             return d
 
         if namespace==None:
-            if include_pylons_variables == False:
-                raise BuffetError('You must specify ``namespace`` if ``include_pylons_variables`` is False')
+            if include_pylons_variables is False:
+                raise BuffetError('You must specify ``namespace`` if ``include_pylons_variables`` is '
+                                  'False')
             else:
                 namespace = update_namespace({})
         elif isinstance(namespace, dict):
-            if include_pylons_variables == True:
+            if include_pylons_variables is True:
                 keys = namespace.keys()
                 for k in ['c','m','h','g','request','session']:
                     if k in keys:
@@ -308,9 +301,7 @@ class Buffet(object):
         else:
             namespace = update_namespace(namespace)
         engine_config = getattr(self._local, engine_name)
-        base_path = engine_config['root'].split('/')
-        tmpl_path = template_name.split('/')
-        full_path = os.path.join(*(base_path + tmpl_path))
+        full_path = os.path.join(engine_config['root'], template_name)
         dotted_path = full_path.replace(os.path.sep, '.').lstrip('.')
         page_data = engine_config['engine'].render(namespace, template=dotted_path, **options)
         if as_string:
